@@ -4,15 +4,22 @@ use strict;
 use warnings;
 use utf8;
 
-use Carp qw/croak/;
+use Acme::CoC::Util;
+use Acme::CoC::Types;
 
-our $VERSION = '0.02';
+use Carp qw/croak/;
+use Smart::Args;
+
+our $VERSION = '0.03';
 
 sub role {
-    my ($self, $command) = @_;
+    args_pos
+        my $self,
+        my $command => {isa => 'command'},
+    ;
 
     # MdN in $command can be separated to M/d/N, and M is the times of roling dice, N is the number of sided dice.
-    return $self->role_skill if $command =~ /^skill$/;
+    return $self->role_skill(get_target($command)) if is_ccb($command);
 
     $command =~ /([1-9][0-9]*)d([1-9][0-9]*)/;
     my $role_result = {
@@ -39,9 +46,23 @@ sub role {
 }
 
 sub role_skill {
-    my ($self) = @_;
-
-    return $self->role('1d100');
+    args_pos
+        my $self,
+        my $target => {isa => 'Maybe[Int]', optional => 1},
+    ;
+    my $role = $self->role('1d100');
+    if (defined $target) {
+        if (is_extream($role->{dices}->[0], $target)) {
+            $role->{result} = 'extream success';
+        } elsif (is_hard($role->{dices}->[0], $target)) {
+            $role->{result} = 'hard success';
+        } elsif (is_failed($role->{dices}->[0], $target)) {
+            $role->{result} = 'failed';
+        } else {
+            $role->{result} = 'normal success';
+        }
+    }
+    return $role;
 }
 
 1;
@@ -80,6 +101,7 @@ Runs "role" with giving "1d100". Usually we can play dice as "1d100" for using s
 This method is for it.
 
     my $result = Acme::CoC::Dice->role_skill;
+    my $result = Acme::CoC::Dice->role_skill(50); ## 50 is given for success threshold.
 
 =head1 AUTHOR
 
